betty.model.event_type module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.model.event_type module

Provide Betty’s ancestry event types.

class betty.model.event_type.Adoption

  Bases: `DuringLifeEventType`

  Someone was adopted.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Baptism

  Bases: `DuringLifeEventType`, `StartOfLifeEventType`

  Someone was baptized.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Birth

  Bases: `CreatableDerivableEventType`, `StartOfLifeEventType`

  Someone was born.

  classmethod comes_before() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Burial

  Bases: `FinalDispositionEventType`

  Someone was buried.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Conference

  Bases: `DuringLifeEventType`

  A conference between people took place.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Confirmation

  Bases: `DuringLifeEventType`

  Someone’s confirmation took place.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Correspondence

  Bases: `EventType`

  People corresponded with each other.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.CreatableDerivableEventType

  Bases: `DerivableEventType`

  Any event type of which the deriver API may create new instances.

  classmethod may_create(person: betty.model.ancestry.Person, lifetime_threshold: int) → bool

    Whether a new event of this type may be created for the given person.

    Parameters:

      - person (`betty.model.ancestry.Person`)

      - lifetime_threshold (`int`)

    Return type:

      `bool`

class betty.model.event_type.Cremation

  Bases: `FinalDispositionEventType`

  Someone was cremated.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Death

  Bases: `CreatableDerivableEventType`, `EndOfLifeEventType`

  Someone died.

  classmethod comes_after() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod may_create(person: betty.model.ancestry.Person, lifetime_threshold: int) → bool

    Whether a new event of this type may be created for the given person.

    Parameters:

      - person (`betty.model.ancestry.Person`)

      - lifetime_threshold (`int`)

    Return type:

      `bool`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.DerivableEventType

  Bases: `EventType`

  Any event that that may be updated by the deriver API.

class betty.model.event_type.Divorce

  Bases: `DuringLifeEventType`

  People were divorced.

  classmethod comes_after() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.DivorceAnnouncement

  Bases: `DuringLifeEventType`

  People’s divorce was announced.

  classmethod comes_after() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod comes_before() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.DuringLifeEventType

  Bases: `EventType`

  Any event that only ever takes place during someone’s life, e.g. after their birth and before their death.

  classmethod comes_after() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod comes_before() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

class betty.model.event_type.Emigration

  Bases: `DuringLifeEventType`

  Someone emigrated from a place.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.EndOfLifeEventType

  Bases: `EventType`

  An event that indicates the end of someone’s life.

  This includes someone’s actual death, but also other types of events that take place close to someone’s death and as such are indicators that that person died around the time of the end-of-life event.

class betty.model.event_type.Engagement

  Bases: `DuringLifeEventType`

  People got engaged with the intent to marry.

  classmethod comes_before() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.EventType

  Bases: `object`

  Define an `betty.model.ancestry.Event` type.

  static __new__(cls)
  classmethod comes_after() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod comes_before() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.EventTypeProvider

  Bases: `object`

  Provide additional event types.

  property entity_types: set[type[EventType]]

    The event types.

class betty.model.event_type.FinalDispositionEventType

  Bases: `PostDeathEventType`, `DerivableEventType`, `EndOfLifeEventType`

  Someone’s final disposition took place.

class betty.model.event_type.Funeral

  Bases: `FinalDispositionEventType`

  Someone’s funeral took place.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Immigration

  Bases: `DuringLifeEventType`

  Someone immigrated to a place.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Marriage

  Bases: `DuringLifeEventType`

  People were married.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.MarriageAnnouncement

  Bases: `DuringLifeEventType`

  People’s marriage was announced.

  classmethod comes_before() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Missing

  Bases: `DuringLifeEventType`

  Someone went missing.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Occupation

  Bases: `DuringLifeEventType`

  Someone’s occupation, e.g. their main recurring activity.

  This may include employment, education, stay at home parent, etc.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.PostDeathEventType

  Bases: `EventType`

  An event that only ever happens after someone’s death.

  classmethod comes_after() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes after.

    The returned event types come before this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

class betty.model.event_type.PreBirthEventType

  Bases: `EventType`

  Any event that only ever takes place before someone’s birth.

  classmethod comes_before() → set[type[betty.model.event_type.EventType]]

    Get the event types that this event type comes before.

    The returned event types come after this event type.

    Return type:

      `set`[`type`[`betty.model.event_type.EventType`]]

class betty.model.event_type.Residence

  Bases: `DuringLifeEventType`

  Someone resided/lived in a place.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Retirement

  Bases: `DuringLifeEventType`

  Someone retired.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.StartOfLifeEventType

  Bases: `EventType`

  An event that indicates the start of someone’s life.

  This includes someone’s actual birth, but also other types of events that take place close to someone’s birth and as such are indicators that that person was born around the time of the start-of-life event.

class betty.model.event_type.UnknownEventType

  Bases: `EventType`

  Described an event for which no more specific type is known.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`

class betty.model.event_type.Will

  Bases: `PostDeathEventType`

  Someone’s will and testament came into effect.

  classmethod label() → betty.locale.Str

    Get the human-readable label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    Get the machine name.

    Return type:

      `str`